@@ -163,11 +163,12 @@ pub(crate) fn submit_gossip_stats(
     gossip: &RwLock<CrdsGossip>,
     stakes: &HashMap<Pubkey, u64>,
 ) {
-    let (table_size, num_nodes, purged_values_size, failed_inserts_size) = {
+    let (table_size, num_nodes, num_pubkeys, purged_values_size, failed_inserts_size) = {
         let gossip = gossip.read().unwrap();
         (
             gossip.crds.len(),
             gossip.crds.num_nodes(),
+            gossip.crds.num_pubkeys(),
             gossip.crds.num_purged(),
             gossip.pull.failed_inserts.len(),
         )
@@ -192,6 +193,7 @@ pub(crate) fn submit_gossip_stats(
         ("failed_inserts_size", failed_inserts_size as i64, i64),
         ("num_nodes", num_nodes as i64, i64),
         ("num_nodes_staked", num_nodes_staked as i64, i64),
+        ("num_pubkeys", num_pubkeys, i64),
     );
     datapoint_info!(
         "cluster_info_stats2",
